# -*- coding: iso_8859_1 -*-

import numpy as np
import matplotlib.pyplot as plt
from aspylib import astro, calib, conf

#------------------------------------------------------------------------------------
#	purpose
#------------------------------------------------------------------------------------
#
#	This script loads a list of calibrated images. Then it co-aligns and combines them with the specified method 
#	(here: mean co-addition is used, which is the default option of the calib.coalign_coadd_and_save() function).
#
#------------------------------------------------------------------------------------
#	input parameters
#------------------------------------------------------------------------------------

#--- folders and imagenames ---
Folder = conf.folder + "test_calibration\\"
Imagelist = [Folder + "processed\\images\\ngc7635-calibrated-" + str(i+1) + ".fits" for i in range(30)]
final_Image = Folder + "processed\\ngc7635-final.fits"

#--- others ---
mult = 10

#--- additional information (for FITS headers) ---
Config = 0
Headers = {'OBJECT': ['ngc7635 (coadded)','']}

#------------------------------------------------------------------------------------
#	script
#------------------------------------------------------------------------------------

#--- loading, co-aligning and co-adding images ---
images = astro.get_imagedata(Imagelist)	
images_aligned, shifts = calib.coalign(images, fit_area=10, nb_stars=24, excl=[], incl=[], text_display=False, return_shifts=True)
image_final = mult*astro.add_median(images_aligned)
print("")
print("final image computed")

#creating headers
headerdict = astro.create_headers(Config, [Imagelist[0]])[0]
headerdict.update(Headers)

#updating headers
if astro.get_headervalues([Imagelist[0]], 'EXPOSURE')[0]!='':
	Exp = np.sum(np.array(astro.get_headervalues(Imagelist, 'EXPOSURE')))
else:
	Exp = np.sum(np.array(astro.get_headervalues(Imagelist, 'EXPTIME')))
Dateobs = sorted(astro.get_headervalues(Imagelist, 'DATE-OBS'))[0]
Dateend = sorted(astro.get_headervalues(Imagelist, 'DATE-END'))[-1]
try:
	del headerdict['EXPTIME']
except KeyError:
	pass
headerdict.update({'EXPOSURE':[Exp,'Total exposure (s)'], 'DATE-OBS':[Dateobs,''],'DATE-END':[Dateend,'']})

#saving image
astro.save_imagelist(image_final, [headerdict], [final_Image])
print("")
print(final_Image + ' saved')

#displaying the shifts
plt.figure()
plt.plot(shifts[:,0], label='X')
plt.plot(shifts[:,1], label='Y')
plt.legend()
plt.show()

#displaying image
astro.display(image_final)