# -*- coding: iso_8859_1 -*-

import matplotlib.pyplot as plt
from aspylib import astro, calib, conf

#------------------------------------------------------------------------------------
#	purpose
#------------------------------------------------------------------------------------
#
#	This script loads a list of raw images and calibration frames (dark and flat).
#	Then it calibrates the images, and co-aligns them.
#
#------------------------------------------------------------------------------------
#	input parameters
#------------------------------------------------------------------------------------

#--- folders ---
Folder = conf.folder+"test_calibration\\"

#--- input frames ---
Imagelist = [Folder + "sources\\images\\ngc7635-" + str(i+1) + ".fits" for i in range(30)]
Darklist = [Folder + "sources\\dark\\dark-" + str(i+1) + ".fits" for i in range(20)]
Flat = [Folder+ "flat-final.fits"]

#--- output frames ---
Imagelist2 = [Folder+ "processed\\images\\ngc7635-coaligned-" + str(i+1) + ".fits" for i in range(30)]

#--- additional information (for FITS headers) ---
Config = 0
More_headers = {'OBJECT': ['ngc7635 (coaligned)','']}

#------------------------------------------------------------------------------------
#	script
#------------------------------------------------------------------------------------

#load image data
images = astro.get_imagedata(Imagelist)
darkframes = astro.get_imagedata(Darklist)
flatframe = astro.get_imagedata(Flat)

#calibration and co-alignment
darkframe = astro.add_median(darkframes)
images_calibrated =  calib.calibrate(images, darkframe, flatframe)
print("")
print("calibration done")
images_aligned, shifts = calib.coalign(images_calibrated, fit_area=10, nb_stars=24, excl=[], incl=[], text_display=False, return_shifts=True)
print("")
print("images co-aligned")

#save images
headerdictlist = astro.create_headers(Config, Imagelist)
newheaderdictlist = []
for headerdict in headerdictlist:
	headerdict.update(More_headers)
	newheaderdictlist.append(headerdict)
	
#saving calibrated images
astro.save_imagelist(images_aligned, newheaderdictlist, Imagelist2)
print("")
print("co-aligned images saved")

#displaying the shifts
plt.figure()
plt.plot(shifts[:,0], label='X')
plt.plot(shifts[:,1], label='Y')
plt.legend()
plt.show()
