# -*- coding: iso_8859_1 -*-

from aspylib import astro, calib, conf

#------------------------------------------------------------------------------------
#	purpose
#------------------------------------------------------------------------------------
#
#	This script loads a list of raw images and calibration frames (dark and flat).
#	Then it calibrates the images.
#
#------------------------------------------------------------------------------------
#	input parameters
#------------------------------------------------------------------------------------

#--- folders ---
Folder = conf.folder+"test_calibration\\"

#--- input frames ---
Imagelist = [Folder + "sources\\images\\ngc7635-" + str(i+1) + ".fits" for i in range(30)]
Darklist = [Folder + "sources\\dark\\dark-" + str(i+1) + ".fits" for i in range(20)]
Flat = [Folder + "flat-final.fits"]

#--- output frames ---
Imagelist2 = [Folder+ "processed\\images\\ngc7635-calibrated-" + str(i+1) + ".fits" for i in range(30)]

#--- FITS headers ---
Config = 0
Headers = {'OBJECT': ['ngc7635 (calibrated)','']}

#------------------------------------------------------------------------------------
#	script
#------------------------------------------------------------------------------------

#load image data
images = astro.get_imagedata(Imagelist)
darkframes = astro.get_imagedata(Darklist)
flatframe = astro.get_imagedata(Flat)

#computing master dark frame
darkframe = astro.add_median(darkframes)

#calibration
images_calibrated =  calib.calibrate(images, darkframe, flatframe)
print("")
print("calibration done")

#creating headers
headerdictlist = astro.create_headers(Config, Imagelist)
newheaderdictlist = []
for headerdict in headerdictlist:
	headerdict.update(Headers)
	newheaderdictlist.append(headerdict)
	
#saving calibrated images
astro.save_imagelist(images_calibrated, newheaderdictlist, Imagelist2)
print("")
print("calibrated images saved")

#displaying the images before/after calibration
astro.display(images[0,:,:])
image_calibrated = astro.get_imagedata([Imagelist2[0]])		#reload because when saving an image, the min and max are truncated, removing the outliers
astro.display(image_calibrated)
