# -*- coding: iso_8859_1 -*-

import numpy as np
from aspylib import astro, calib, conf

#------------------------------------------------------------------------------------
#	purpose
#------------------------------------------------------------------------------------
#
#	This script loads a list of raw images and calibration frames (dark and flat).
#	Then it calibrates the images, co-aligns and co-adds them with the specified method
#	(here: mean co-addition is used, which is the default option of the calib.calibrate_coalign_coadd_and_save() function).
#
#------------------------------------------------------------------------------------
#	input parameters
#------------------------------------------------------------------------------------

#--- folders ---
Folder = conf.folder+"test_calibration\\"

#--- input frames ---
Imagelist = [Folder + "sources\\images\\ngc7635-" + str(i+1) + ".fits" for i in range(30)]
Darklist = [Folder + "sources\\dark\\dark-" + str(i+1) + ".fits" for i in range(20)]
Flat = [Folder+ "flat-final.fits"]

#--- output frames ---
final_Image = Folder + "processed\\ngc7635-final.fits"

#--- others ---
mult = 10

#--- additional information (for FITS headers) ---
Config = 0
Headers = {'OBJECT': ['ngc7635 (coadded)','']}

#------------------------------------------------------------------------------------
#	script
#------------------------------------------------------------------------------------

#load image data
images = astro.get_imagedata(Imagelist)
darkframes = astro.get_imagedata(Darklist)
flatframe = astro.get_imagedata(Flat)

#calibration, co-alignment and co-addition
darkframe = astro.add_median(darkframes)
images_calibrated =  calib.calibrate(images, darkframe, flatframe)
print("")
print("calibration done")
images_aligned = calib.coalign(images_calibrated, fit_area=10, nb_stars=12, excl=[], incl=[], text_display=False, return_shifts=False)
print("")
print("images co-aligned")
image_final = mult*astro.add_median(images_aligned)
print("")
print("final image computed")

#creating headers
headerdict = astro.create_headers(Config, [Imagelist[0]])[0]
headerdict.update(Headers)

#updating headers
if astro.get_headervalues([Imagelist[0]], 'EXPOSURE')[0]!='':
	Exp = np.sum(np.array(astro.get_headervalues(Imagelist, 'EXPOSURE')))
else:
	Exp = np.sum(np.array(astro.get_headervalues(Imagelist, 'EXPTIME')))
Dateobs = sorted(astro.get_headervalues(Imagelist, 'DATE-OBS'))[0]
Dateend = sorted(astro.get_headervalues(Imagelist, 'DATE-END'))[-1]
try:
	del headerdict['EXPTIME']
except KeyError:
	pass
headerdict.update({'EXPOSURE':[Exp,'Total exposure (s)'], 'DATE-OBS':[Dateobs,''],'DATE-END':[Dateend,'']})

#saving image
astro.save_imagelist(image_final, [headerdict], [final_Image])
print("")
print(final_Image + ' saved')

#displaying final image
image_final = astro.get_imagedata([final_Image])	#reload because when saving an image, the min and max are truncated, removing the outliers
astro.display(image_final)