# -*- coding: iso_8859_1 -*-

from aspylib import astro, conf
import numpy as np
import matplotlib.pyplot as plt
import os, time

#------------------------------------------------------------------------------------
#	Purpose
#------------------------------------------------------------------------------------
#
#	this scripts detects all new FITS files written to the specified folder
#	it computes their
#	- min, mean and max values
#	- median PSF fwhm (small, large) over the detected stars
#	- X and Y shifts wrt a specified reference image
#
#------------------------------------------------------------------------------------
#	Input parameters
#------------------------------------------------------------------------------------

#path + file information
path_to_watch = conf.folder + "test\\"
reference_image = "image-1.fits"

#fit parameters
fit_area = 12
nb_stars = 12

#------------------------------------------------------------------------------------
#	Script
#------------------------------------------------------------------------------------

before = dict ([(f, None) for f in os.listdir (path_to_watch)]) 

#first file to be used as a reference for drift
image_ref = astro.get_imagedata([path_to_watch+reference_image])

print("")
print('Define asteroid position so that it is removed from shift calculation')
xy = astro.select(image_ref, nb=1, facecolor = 'red', marker = '+')
x0 = xy[0][0]
y0 = xy[0][1]
stars_ref = astro.find_stars_accurate(image_ref, nb_stars, fit_area, excluded=[[x0-10, x0+10, y0-10, y0+10]], filter=1)


#loop to detect new fits files created in folder
while 1: 
	time.sleep (10) 
	after = dict ([(f, None) for f in os.listdir (path_to_watch)]) 
	added = [f for f in after if not f in before] 
	#if added: print("Added: ", ", ".join (added))
	before = after 

	for f in added:
		if astro.check_extension(f):
			#loading new images
			image = astro.get_imagedata([path_to_watch+f])
			
			#calculating statistics
			mean = np.mean(image.flatten())
			maxi = np.max(image.flatten())
			mini = np.min(image.flatten())
			print("                   min: ", mini, "     max: ", maxi, "     mean: ", mean)

			#fitting stars
			fwhm_small, fwhm_large, angle = astro.mean_psf(image, fit_area, nb_stars)
			print("                   FWHM small = %.2f" % fwhm_small)
			print("                   FWHM large = %.2f" % fwhm_large)

			#finding shift wrt reference image
			stars = astro.find_stars_accurate(image, nb_stars-2, fit_area, excluded=[[x0-10, x0+10, y0-10, y0+10]], filter=1)
			dx, dy = astro.find_shift_stars_matching(stars_ref, stars)
			print("                   X and Y shifts = ", dx, dy)
			print("")
