# -*- coding: iso_8859_1 -*-

from aspylib import photometry, conf
import numpy as np
import matplotlib.pyplot as plt

#------------------------------------------------------------------------------------
#	Purpose 
#------------------------------------------------------------------------------------
#
#	Loads the file that contains the information about image statistics (min, max, sky background) that was created during execution of the scripts "photometry_run.py" or "photosearch_run.py".
#	Then, displays the image statistics for all images that have not been rejected.
#
#------------------------------------------------------------------------------------
#	Input parameters 
#------------------------------------------------------------------------------------

Folder = conf.folder
Filename = Folder + 'test_01_check_images.txt'

#------------------------------------------------------------------------------------
#	Script
#------------------------------------------------------------------------------------

imagelist, globminmax, minmax, bgnd, varbgnd = photometry.load_imagestats(Filename)
ind = list(np.array(np.arange(1,len(imagelist)+1), dtype=np.int))

if len(globminmax)==0:
	plt.figure(figsize=(8,10))
	ax = plt.subplot(2,1,1)
	ax.plot(ind,minmax[:,0],label='min')
	ax.plot(ind,minmax[:,1],label='max')
	ax.set_title('Min and Max signals (on selected subimage)')
	ax.set_xlabel('image number')
	ax.set_ylabel('Min and Max signals')
	ax.grid()

	ax = plt.subplot(2,1,2)
	for i in range(np.shape(bgnd)[1]):
		ax.plot(ind,bgnd[:,i])
	ax.grid()
	ax.set_title('Image background uniformity')
	ax.set_xlabel('image number')
	ax.set_ylabel('Background uniformity')
	plt.show()

else:
	fig = plt.figure(figsize=(8,10))
	fig.canvas.set_window_title("Dynamic range") 
	ax = fig.add_subplot(2,1,1)
	ax.plot(ind,globminmax[:,0],label='Max')
	ax.plot(ind,globminmax[:,1],label='Min')
	ax.plot(ind,globminmax[:,1]-globminmax[:,0],label='Dynamic range')
	ax.set_title("Min, Max, Max-Min (on full image)")
	ax.set_xlabel("image number")
	ax.grid()
	ax = fig.add_subplot(2,1,2)
	ax.plot(ind,minmax[:,0],label='Max')
	ax.plot(ind,minmax[:,1],label='Min')
	ax.plot(ind,minmax[:,1]-minmax[:,0],label='Dynamic range')
	ax.set_title("Min, Max, Max-Min (on selected sub-part)")
	ax.set_xlabel("image number")
	ax.grid()
	plt.show()

	fig = plt.figure(figsize=(8,10))
	fig.canvas.set_window_title("Background uniformity") 
	ax = fig.add_subplot(2,1,1)
	for i in range(np.shape(bgnd)[1]):
		ax.plot(ind,bgnd[:,i])
	ax.set_title("Deviation from uniform sky background\n(measured at center + 4 corners)")
	ax.set_xlabel("image number")
	ax.grid()
	ax = fig.add_subplot(2,1,2)
	for i in range(np.shape(varbgnd)[1]):
		ax.plot(ind,varbgnd[:,i])
	ax.set_title("Variations of the above plot")
	ax.set_xlabel("image number")
	ax.grid()	
	plt.show()
	