# -*- coding: iso_8859_1 -*-

import matplotlib.pyplot as plt
import matplotlib.cm as cm
import matplotlib.animation as anim

from aspylib import astro, conf
import numpy as np
import time

#------------------------------------------------------------------------------------
#	Purpose 
#------------------------------------------------------------------------------------
#
#	Makes a blinking image with the 1st and 100th image (or last image if there are less than 100) in a series.
#	If the images are co-aligned, the script can be used to detect moving objects (asteroids).
#
#------------------------------------------------------------------------------------
#	Input parameters
#------------------------------------------------------------------------------------

#--- calibrated images ---
Folder = conf.folder
Imagelist = [Folder + "images-aligned-" + str(i+1) + ".fit" for i in range(100)]

#------------------------------------------------------------------------------------
#	Script
#------------------------------------------------------------------------------------

#------ displaying 1st and 100th (or last) images ------
im1 = astro.get_imagedata([Imagelist[0]])
if len(Imagelist)<100:
	im2 = astro.get_imagedata([Imagelist[-1]])
else:
	im2 = astro.get_imagedata(Imagelist[99:100])

#------ conditioning data ------
dmin, dmax = 100., 500.
min = np.ma.median(im1.flatten()) - dmin
max = np.ma.median(im1.flatten()) + dmax
data1 = (im1<min)*min + (im1>max)*max + (im1>=min)*(im1<=max)*im1

min = np.ma.median(im2.flatten()) - dmin
max = np.ma.median(im2.flatten()) + dmax
data2 = (im2<min)*min + (im2>max)*max + (im2>=min)*(im2<=max)*im2

#------ plotting ------
count=0
fig = plt.figure()
ax = fig.add_subplot(1,1,1)
ax.imshow(data1, interpolation='nearest',cmap=cm.gray,origin='lower',vmin = min, vmax =max, aspect='equal', animated=True)

def update(i):
	global count
	count = count+1
	time.sleep(0.2)
	plt.cla()
	if (count%2==0):
		ax.imshow(data1, interpolation='nearest',cmap=cm.gray,origin='lower',vmin = min, vmax =max, aspect='equal', animated=True)
	else:
		ax.imshow(data2, interpolation='nearest',cmap=cm.gray,origin='lower',vmin = min, vmax =max, aspect='equal', animated=True)
	
a = anim.FuncAnimation(fig, update, frames=1000, repeat=True)
plt.show()
