# -*- coding: iso_8859_1 -*-

from aspylib import cdr, astro, conf
import numpy as np
import matplotlib.pyplot as plt

#------------------------------------------------------------------------------------
#	Purpose
#------------------------------------------------------------------------------------
#
#	Reads a list of lightcurve files (with CourbRot format) and searches the most likely period.
#	For this a Fourier fit is performed for a large number of possible periods.
#	The most likely period is the one with the minimal residual error. It can be used as a starting point in the script Lightcurve_fitperiod.py.
#
#------------------------------------------------------------------------------------
#	Input parameters
#------------------------------------------------------------------------------------

#--- input files ---
Folder = conf.folder + "Mesures\\"

Filelist = ["File_1.txt", \
			"File_2.txt", \
			"File_3.txt", \
			"File_4.txt"]
Filelist = [Folder + ff for ff in Filelist]

#type of target (either "asteroid" or "star")
#target = "asteroid"		
target = "star"

#for time correction of variable star
alpha = astro.hours_to_decdegrees('12:36:27.32')
delta = astro.degrees_to_decdegrees('-02:25:32.6')

#for time correction of asteroid
file_DistanceToEarth = Folder + "dist.txt"

#False if the same reference stars are used for all the series (less fit parameters)
fit_offsets = True

#fit parameters
T0 = 2455690.0			#reference time (this parameter defines the time when phase = 0. It is also needed in the calculation to avoid too large numbers for the epochs)
nb_harmo = 2			#number of Fourier harmonics for fitting the lightcurve
periods = np.linspace(0.05, 0.8, 400)		#possible periods, in days

#------------------------------------------------------------------------------------
#	Script
#------------------------------------------------------------------------------------
#------------------------------------------------------------------------------------
#	loading data
#------------------------------------------------------------------------------------

if fit_offsets:
	alldata = cdr.load_magdata(Filelist, zero_mean=True)
else:
	alldata = cdr.load_magdata(Filelist, zero_mean=False)

#------ time correction (choose asteroid or variable star) ------
if target == "asteroid":
	alldata = cdr.time_correction(alldata, 1, file_DistanceToEarth)			#time correction for asteroid
else:
	alldata = cdr.time_correction(alldata, 2, [alpha,delta])				#time correction for variable star

cdr.plot_magdata(alldata, 'Measurements')

#------------------------------------------------------------------------------------
#	searching period
#------------------------------------------------------------------------------------

error = []

for period in list(periods):
	error.append(cdr.fit_givenperiod(alldata, period, T0, nb_harmo = nb_harmo, fit_offsets = fit_offsets))

plt.figure()
plt.plot(periods, np.sqrt(error))
plt.grid()
plt.xlabel("Period in days")
plt.ylabel("Fit error")
plt.title("Search for rotation period")
plt.show()
