# -*- coding: iso_8859_1 -*-

import numpy as np
import platform as pf

from ctypes import c_long, cdll
from numpy.ctypeslib import ndpointer

def get_median(images):
	"""
	---------------------
	Purpose
	Calculates the median values of all pixels for each image in a list of images
	The algorithm to calculate the median values is based on the Wirth method. A C implementation from Devillard (from http://ndevilla.free.fr/median/median/index.html) is used, after correction of a typo.
	---------------------
	Inputs
	* images (2D or 3D Numpy array) = array that contains the data of one image (2D case) or the data of a list of images (3D case).
	---------------------
	Output (list) = Python list containing the median values of each image (float numbers).
	---------------------
	"""

	ierror = 0
	while True:
		try:
			if len(images.shape)==2:
				dim = 1
				dim_x, dim_y = images.shape
			else:
				dim, dim_x, dim_y = images.shape

			indata = np.ascontiguousarray(np.array(images, dtype=np.float32))
			outdata = np.ascontiguousarray(np.empty((dim), dtype=np.float32))

			if pf.system()=='Windows':
				cdll.median.Median2.argtypes = [c_long, c_long, c_long, ndpointer(dtype=np.float32), ndpointer(dtype=np.float32)]
				cdll.median.Median2(dim,dim_x,dim_y,indata,outdata)	
			elif pf.system()=='Linux':
				mydll = cdll.LoadLibrary("libmedian.so")
				mydll.Median2.argtypes = [c_long, c_long, c_long, ndpointer(dtype=np.float32), ndpointer(dtype=np.float32)]
				mydll.Median2(dim,dim_x,dim_y,indata,outdata)	

			del indata
			break
		except:
			print("error in aspylib.astro.get_median()")
			ierror+=1
			if ierror>3:
				raise Exception("more than 3 consecutive failures, execution stopped")
			pass

	return outdata
