# -*- coding: iso_8859_1 -*-

import numpy as np

def mirror_horiz(images):
	"""
	---------------------
	Purpose
	This function is inverting the vertical direction for all images in a list of FITS images.
	The resulting images are horizontally-mirrored.
	---------------------
	Inputs
	* images (2D or 3D Numpy array) = array that contains the data of one image (2D case) or the data of a list of images (3D case).
	---------------------
	Output (2D or 3D Numpy array) = transformed image data.
	---------------------
	"""
	
	if len(images.shape)==2:
		images2 = images[:,::-1]
	elif len(images.shape)==3:
		images2 = images[:,:,::-1]

	return images2
	
def mirror_vert(images):
	"""
	---------------------
	Purpose
	This function is inverting the horizontal direction for all images in a list of FITS images.
	The resulting images are vertically-mirrored.
	---------------------
	Inputs
	* images (2D or 3D Numpy array) = array that contains the data of one image (2D case) or the data of a list of images (3D case).
	---------------------
	Output (2D or 3D Numpy array) = transformed image data.
	---------------------
	"""
	
	if len(images.shape)==2:
		images2 = images[::-1,:]
	elif len(images.shape)==3:
		images2 = images[:,::-1,:]

	return images2

def rot_90(images):
	"""
	---------------------
	Purpose
	This function is clockwise rotating all images in a list of FITS images by 90 degrees.
	---------------------
	Inputs
	* images (2D or 3D Numpy array) = array that contains the data of one image (2D case) or the data of a list of images (3D case).
	---------------------
	Output (2D or 3D Numpy array) = transformed image data.
	---------------------
	"""
	
	if len(images.shape)==2:
		images2 = np.rot90(images)
	elif len(images.shape)==3:
		images2 = np.transpose(images,(1,2,0))
		images2 = np.rot90(images2)
		images2 = np.transpose(images,(2,0,1))

	return images2

def rot_180(images):
	"""
	---------------------
	Purpose
	This function is rotating all images in a list of FITS images by 180 degrees.
	---------------------
	Inputs
	* images (2D or 3D Numpy array) = array that contains the data of one image (2D case) or the data of a list of images (3D case).
	---------------------
	Output (2D or 3D Numpy array) = transformed image data.
	---------------------
	"""
	
	if len(images.shape)==2:
		images2 = np.rot90(images,2)
	elif len(images.shape)==3:
		images2 = np.transpose(images,(1,2,0))
		images2 = np.rot90(images2,2)
		images2 = np.transpose(images,(2,0,1))

	return images2

def rot_270(images):
	"""
	---------------------
	Purpose
	This function is clockwise rotating all images in a list of FITS images by 270 degrees.
	---------------------
	Inputs
	* images (2D or 3D Numpy array) = array that contains the data of one image (2D case) or the data of a list of images (3D case).
	---------------------
	Output (2D or 3D Numpy array) = transformed image data.
	---------------------
	"""
	
	if len(images.shape)==2:
		images2 = np.rot90(images,3)
	elif len(images.shape)==3:
		images2 = np.transpose(images,(1,2,0))
		images2 = np.rot90(images2,3)
		images2 = np.transpose(images,(2,0,1))

	return images2
