# -*- coding: iso_8859_1 -*-

import numpy as np
from aspylib import astro

def find_hotpixels(darkframe, target_nb):
	"""
	---------------------
	Purpose
	Given a dark image, returns the positions (x,y) of the brightest hot pixels.
	---------------------
	Inputs
	* darkframe (2D Numpy array) = data of a single dark image, typically obtained after co-addition of a series of dark images.
	* target_nb (integer) = targetted number of hot pixels.	The number of returned hot pixels lies in the interval [0.5*target_nb;2.0*target_nb]. No ordering of the hot pixels is done (e.g. according to their brightness).
	---------------------
	* hotpixels (2D Numpy array) = array in the for [[x1,y1], [x1,y2], ..., [xn,yn]] for the (x,y) coordinates of the hot pixels in the image.
	---------------------
	"""
	#---------------------------------
	#possible issues/improvements:
	# (1) factor a=0.25 (so that th3=th1*(1-a)+th2*a) may need to be adjusted so that 2 consecutive iterations don't miss the interval [0.5*target_nb; 2.0*target_nb]
	# (2) it may not be possible to reach the right number of hot pixels target_nb within the range [th1;th2]
	#---------------------------------

	y,x = np.meshgrid(np.arange(1,np.shape(darkframe)[1]+1),np.arange(1,np.shape(darkframe)[0]+1))
	test = (x>1)*(x<np.shape(darkframe)[0])*(y>1)*(y<np.shape(darkframe)[1])		#test is True everywhere except at the image border (1 pixel width)

	th1 = np.mean(darkframe.flatten())
	hotpixels = (darkframe> th1)* test
	nb1 = np.sum(hotpixels.flatten())
	
	th2 = 10000
	hotpixels = (darkframe> th2)* test
	nb2 = np.sum(hotpixels.flatten())
	
	while True:
		th3 = th1*0.75+th2*0.25
		hotpixels = (darkframe> th3)* test
		nb3 = np.sum(hotpixels.flatten())
		
		if nb3>target_nb*2.:
			th1 = th3
			nb1 = nb3
		elif nb3<target_nb*0.5:
			th2 = th3
			nb2 = nb3
		else:
			break

	return hotpixels

